# Appendix I: SPDX License List

The SPDX License List is a list of commonly found licenses and exceptions used for open source and other collaborative software. The purpose of the SPDX License List is to enable easy and efficient identification of such licenses and exceptions in an SPDX document (or elsewhere). The SPDX License List includes a standardized short identifier, full name for each license, vetted license text, other basic information, and a canonical permanent URL for each license and exception. By providing a short identifier, users can efficiently refer to a license without having to redundantly reproduce the full license. License exceptions can be used with the License Expression Syntax operator, "WITH" to create a license with an exception.

* [License Exceptions][exceptions]: The list of commonly found exceptions to open source licenses, which can be used with the License Expression operator, "WITH" to create a license with an exception.
* Master Files: The HTML pages you see here are generated from the master files for the SPDX License List. The master files include a spreadsheet listing all the licenses, deprecated licenses, and license exceptions; and the text for each license in a .txt file. These files are available in a Git repository.
* Overview: For general information about the SPDX License List, including principles for inclusion of a license and an explanation of the fields contained on the list.
* [Matching Guidelines][matching]: Guidelines for what constitutes a license match to the SPDX License List. For licenses that include markup, the license text on the HTML pages here will display omitable text in blue and replaceable text in red (see Guideline #2 for more information).
* [Request New License][new-license]: For instructions on how to propose additional licenses or license exceptions be added to the SPDX License List.

[exceptions]: https://spdx.org/licenses/exceptions-index.html
[matching]: https://spdx.org/spdx-license-list/matching-guidelines
[new-license]: https://spdx.org/spdx-license-list/request-new-license

The following table contains the full names and short identifiers for the SPDX License List, v2.5 which was released July 2016. For the full and most up-to-date version of the SPDX License List as well as other related information, please see [http://spdx.org/licenses/](http://spdx.org/licenses/)

## I.1 Licenses with Short Identifiers <a name="I.1"></a>

| Full Name of License                                           | Short Identifier                         | OSI? |
|----------------------------------------------------------------|------------------------------------------|------|
| BSD Zero Clause License                                        | [0BSD][]                                 | Y    |
| Attribution Assurance License                                  | [AAL][]                                  | Y    |
| Abstyles License                                               | [Abstyles][]                             |      |
| Adobe Systems Incorporated Source Code License Agreement       | [Adobe-2006][]                           |      |
| Adobe Glyph List License                                       | [Adobe-Glyph][]                          |      |
| Amazon Digital Services License                                | [ADSL][]                                 |      |
| Academic Free License v1.1                                     | [AFL-1.1][]                              | Y    |
| Academic Free License v1.2                                     | [AFL-1.2][]                              | Y    |
| Academic Free License v2.0                                     | [AFL-2.0][]                              | Y    |
| Academic Free License v2.1                                     | [AFL-2.1][]                              | Y    |
| Academic Free License v3.0                                     | [AFL-3.0][]                              | Y    |
| Afmparse License                                               | [Afmparse][]                             |      |
| Affero General Public License v1.0                             | [AGPL-1.0][]                             |      |
| GNU Affero General Public License v3.0                         | [AGPL-3.0][]                             | Y    |
| Aladdin Free Public License                                    | [Aladdin][]                              |      |
| AMD's plpa_map.c License                                       | [AMDPLPA][]                              |      |
| Apple MIT License                                              | [AML][]                                  |      |
| Academy of Motion Picture Arts and Sciences BSD                | [AMPAS][]                                |      |
| ANTLR Software Rights Notice                                   | [ANTLR-PD][]                             |      |
| Apache License 1.0                                             | [Apache-1.0][]                           |      |
| Apache License 1.1                                             | [Apache-1.1][]                           | Y    |
| Apache License 2.0                                             | [Apache-2.0][]                           | Y    |
| Adobe Postscript AFM License                                   | [APAFML][]                               |      |
| Adaptive Public License 1.0                                    | [APL-1.0][]                              | Y    |
| Apple Public Source License 1.0                                | [APSL-1.0][]                             | Y    |
| Apple Public Source License 1.1                                | [APSL-1.1][]                             | Y    |
| Apple Public Source License 1.2                                | [APSL-1.2][]                             | Y    |
| Apple Public Source License 2.0                                | [APSL-2.0][]                             | Y    |
| Artistic License 1.0                                           | [Artistic-1.0][]                         | Y    |
| Artistic License 1.0 w/clause 8                                | [Artistic-1.0-cl8][]                     | Y    |
| Artistic License 1.0 (Perl)                                    | [Artistic-1.0-Perl][]                    | Y    |
| Artistic License 2.0                                           | [Artistic-2.0][]                         | Y    |
| Bahyph License                                                 | [Bahyph][]                               |      |
| Barr License                                                   | [Barr][]                                 |      |
| Beerware License                                               | [Beerware][]                             |      |
| BitTorrent Open Source License v1.0                            | [BitTorrent-1.0][]                       |      |
| BitTorrent Open Source License v1.1                            | [BitTorrent-1.1][]                       |      |
| Borceux license                                                | [Borceux][]                              |      |
| "BSD 2-clause ""Simplified"" License"                          | [BSD-2-Clause][]                         | Y    |
| BSD 2-clause FreeBSD License                                   | [BSD-2-Clause-FreeBSD][]                 |      |
| BSD 2-clause NetBSD License                                    | [BSD-2-Clause-NetBSD][]                  |      |
| "BSD 3-clause ""New"" or ""Revised"" License"                  | [BSD-3-Clause][]                         | Y    |
| BSD with attribution                                           | [BSD-3-Clause-Attribution][]             |      |
| BSD 3-clause Clear License                                     | [BSD-3-Clause-Clear][]                   |      |
| Lawrence Berkeley National Labs BSD variant license            | [BSD-3-Clause-LBNL][]                    |      |
| BSD 3-Clause No Nuclear License                                | [BSD-3-Clause-No-Nuclear-License][]      |      |
| BSD 3-Clause No Nuclear License 2014                           | [BSD-3-Clause-No-Nuclear-License-2014][] |      |
| BSD 3-Clause No Nuclear Warranty                               | [BSD-3-Clause-No-Nuclear-Warranty][]     |      |
| "BSD 4-clause ""Original"" or ""Old"" License"                 | [BSD-4-Clause][]                         |      |
| BSD-4-Clause (University of California-Specific)               | [BSD-4-Clause-UC][]                      |      |
| BSD Protection License                                         | [BSD-Protection][]                       |      |
| BSD Source Code Attribution                                    | [BSD-Source-Code][]                      |      |
| Boost Software License 1.0                                     | [BSL-1.0][]                              | Y    |
| bzip2 and libbzip2 License v1.0.5                              | [bzip2-1.0.5][]                          |      |
| bzip2 and libbzip2 License v1.0.6                              | [bzip2-1.0.6][]                          |      |
| Caldera License                                                | [Caldera][]                              |      |
| Computer Associates Trusted Open Source License 1.1            | [CATOSL-1.1][]                           | Y    |
| Creative Commons Attribution 1.0                               | [CC-BY-1.0][]                            |      |
| Creative Commons Attribution 2.0                               | [CC-BY-2.0][]                            |      |
| Creative Commons Attribution 2.5                               | [CC-BY-2.5][]                            |      |
| Creative Commons Attribution 3.0                               | [CC-BY-3.0][]                            |      |
| Creative Commons Attribution 4.0                               | [CC-BY-4.0][]                            |      |
| Creative Commons Attribution Non Commercial 1.0                | [CC-BY-NC-1.0][]                         |      |
| Creative Commons Attribution Non Commercial 2.0                | [CC-BY-NC-2.0][]                         |      |
| Creative Commons Attribution Non Commercial 2.5                | [CC-BY-NC-2.5][]                         |      |
| Creative Commons Attribution Non Commercial 3.0                | [CC-BY-NC-3.0][]                         |      |
| Creative Commons Attribution Non Commercial 4.0                | [CC-BY-NC-4.0][]                         |      |
| Creative Commons Attribution Non Commercial No Derivatives 1.0 | [CC-BY-NC-ND-1.0][]                      |      |
| Creative Commons Attribution Non Commercial No Derivatives 2.0 | [CC-BY-NC-ND-2.0][]                      |      |
| Creative Commons Attribution Non Commercial No Derivatives 2.5 | [CC-BY-NC-ND-2.5][]                      |      |
| Creative Commons Attribution Non Commercial No Derivatives 3.0 | [CC-BY-NC-ND-3.0][]                      |      |
| Creative Commons Attribution Non Commercial No Derivatives 4.0 | [CC-BY-NC-ND-4.0][]                      |      |
| Creative Commons Attribution Non Commercial Share Alike 1.0    | [CC-BY-NC-SA-1.0][]                      |      |
| Creative Commons Attribution Non Commercial Share Alike 2.0    | [CC-BY-NC-SA-2.0][]                      |      |
| Creative Commons Attribution Non Commercial Share Alike 2.5    | [CC-BY-NC-SA-2.5][]                      |      |
| Creative Commons Attribution Non Commercial Share Alike 3.0    | [CC-BY-NC-SA-3.0][]                      |      |
| Creative Commons Attribution Non Commercial Share Alike 4.0    | [CC-BY-NC-SA-4.0][]                      |      |
| Creative Commons Attribution No Derivatives 1.0                | [CC-BY-ND-1.0][]                         |      |
| Creative Commons Attribution No Derivatives 2.0                | [CC-BY-ND-2.0][]                         |      |
| Creative Commons Attribution No Derivatives 2.5                | [CC-BY-ND-2.5][]                         |      |
| Creative Commons Attribution No Derivatives 3.0                | [CC-BY-ND-3.0][]                         |      |
| Creative Commons Attribution No Derivatives 4.0                | [CC-BY-ND-4.0][]                         |      |
| Creative Commons Attribution Share Alike 1.0                   | [CC-BY-SA-1.0][]                         |      |
| Creative Commons Attribution Share Alike 2.0                   | [CC-BY-SA-2.0][]                         |      |
| Creative Commons Attribution Share Alike 2.5                   | [CC-BY-SA-2.5][]                         |      |
| Creative Commons Attribution Share Alike 3.0                   | [CC-BY-SA-3.0][]                         |      |
| Creative Commons Attribution Share Alike 4.0                   | [CC-BY-SA-4.0][]                         |      |
| Creative Commons Zero v1.0 Universal                           | [CC0-1.0][]                              |      |
| Common Development and Distribution License 1.0                | [CDDL-1.0][]                             | Y    |
| Common Development and Distribution License 1.1                | [CDDL-1.1][]                             |      |
| CeCILL Free Software License Agreement v1.0                    | [CECILL-1.0][]                           |      |
| CeCILL Free Software License Agreement v1.1                    | [CECILL-1.1][]                           |      |
| CeCILL Free Software License Agreement v2.0                    | [CECILL-2.0][]                           |      |
| CeCILL Free Software License Agreement v2.1                    | [CECILL-2.1][]                           | Y    |
| CeCILL-B Free Software License Agreement                       | [CECILL-B][]                             |      |
| CeCILL-C Free Software License Agreement                       | [CECILL-C][]                             |      |
| Clarified Artistic License                                     | [ClArtistic][]                           |      |
| CNRI Jython License                                            | [CNRI-Jython][]                          |      |
| CNRI Python License                                            | [CNRI-Python][]                          | Y    |
| CNRI Python Open Source GPL Compatible License Agreement       | [CNRI-Python-GPL-Compatible][]           |      |
| Condor Public License v1.1                                     | [Condor-1.1][]                           |      |
| Common Public Attribution License 1.0                          | [CPAL-1.0][]                             | Y    |
| Common Public License 1.0                                      | [CPL-1.0][]                              | Y    |
| Code Project Open License 1.02                                 | [CPOL-1.02][]                            |      |
| Crossword License                                              | [Crossword][]                            |      |
| CrystalStacker License                                         | [CrystalStacker][]                       |      |
| CUA Office Public License v1.0                                 | [CUA-OPL-1.0][]                          | Y    |
| Cube License                                                   | [Cube][]                                 |      |
| curl License                                                   | [curl][]                                 |      |
| Deutsche Freie Software Lizenz                                 | [D-FSL-1.0][]                            |      |
| diffmark license                                               | [diffmark][]                             |      |
| DOC License                                                    | [DOC][]                                  |      |
| Dotseqn License                                                | [Dotseqn][]                              |      |
| DSDP License                                                   | [DSDP][]                                 |      |
| dvipdfm License                                                | [dvipdfm][]                              |      |
| Educational Community License v1.0                             | [ECL-1.0][]                              | Y    |
| Educational Community License v2.0                             | [ECL-2.0][]                              | Y    |
| Eiffel Forum License v1.0                                      | [EFL-1.0][]                              | Y    |
| Eiffel Forum License v2.0                                      | [EFL-2.0][]                              | Y    |
| eGenix.com Public License 1.1.0                                | [eGenix][]                               |      |
| Entessa Public License v1.0                                    | [Entessa][]                              | Y    |
| Eclipse Public License 1.0                                     | [EPL-1.0][]                              | Y    |
| Erlang Public License v1.1                                     | [ErlPL-1.1][]                            |      |
| EU DataGrid Software License                                   | [EUDatagrid][]                           | Y    |
| European Union Public License 1.0                              | [EUPL-1.0][]                             |      |
| European Union Public License 1.1                              | [EUPL-1.1][]                             | Y    |
| Eurosym License                                                | [Eurosym][]                              |      |
| Fair License                                                   | [Fair][]                                 | Y    |
| Frameworx Open License 1.0                                     | [Frameworx-1.0][]                        | Y    |
| FreeImage Public License v1.0                                  | [FreeImage][]                            |      |
| FSF All Permissive License                                     | [FSFAP][]                                |      |
| FSF Unlimited License                                          | [FSFUL][]                                |      |
| FSF Unlimited License (with License Retention)                 | [FSFULLR][]                              |      |
| Freetype Project License                                       | [FTL][]                                  |      |
| GNU Free Documentation License v1.1                            | [GFDL-1.1][]                             |      |
| GNU Free Documentation License v1.2                            | [GFDL-1.2][]                             |      |
| GNU Free Documentation License v1.3                            | [GFDL-1.3][]                             |      |
| Giftware License                                               | [Giftware][]                             |      |
| GL2PS License                                                  | [GL2PS][]                                |      |
| 3dfx Glide License                                             | [Glide][]                                |      |
| Glulxe License                                                 | [Glulxe][]                               |      |
| gnuplot License                                                | [gnuplot][]                              |      |
| GNU General Public License v1.0 only                           | [GPL-1.0][]                              |      |
| GNU General Public License v2.0 only                           | [GPL-2.0][]                              | Y    |
| GNU General Public License v3.0 only                           | [GPL-3.0][]                              | Y    |
| gSOAP Public License v1.3b                                     | [gSOAP-1.3b][]                           |      |
| Haskell Language Report License                                | [HaskellReport][]                        |      |
| Historic Permission Notice and Disclaimer                      | [HPND][]                                 | Y    |
| IBM PowerPC Initialization and Boot Software                   | [IBM-pibs][]                             |      |
| ICU License                                                    | [ICU][]                                  |      |
| Independent JPEG Group License                                 | [IJG][]                                  |      |
| ImageMagick License                                            | [ImageMagick][]                          |      |
| iMatix Standard Function Library Agreement                     | [iMatix][]                               |      |
| Imlib2 License                                                 | [Imlib2][]                               |      |
| Info-ZIP License                                               | [Info-ZIP][]                             |      |
| Intel Open Source License                                      | [Intel][]                                | Y    |
| Intel ACPI Software License Agreement                          | [Intel-ACPI][]                           |      |
| Interbase Public License v1.0                                  | [Interbase-1.0][]                        |      |
| IPA Font License                                               | [IPA][]                                  | Y    |
| IBM Public License v1.0                                        | [IPL-1.0][]                              | Y    |
| ISC License                                                    | [ISC][]                                  | Y    |
| JasPer License                                                 | [JasPer-2.0][]                           |      |
| JSON License                                                   | [JSON][]                                 |      |
| License Art Libre 1.2                                          | [LAL-1.2][]                              |      |
| License Art Libre 1.3                                          | [LAL-1.3][]                              |      |
| Latex2e License                                                | [Latex2e][]                              |      |
| Leptonica License                                              | [Leptonica][]                            |      |
| GNU Library General Public License v2 only                     | [LGPL-2.0][]                             | Y    |
| GNU Lesser General Public License v2.1 only                    | [LGPL-2.1][]                             | Y    |
| GNU Lesser General Public License v3.0 only                    | [LGPL-3.0][]                             | Y    |
| Lesser General Public Licenses For Linguistic Resources        | [LGPLLR][]                               |      |
| libpng License                                                 | [Libpng][]                               |      |
| libtiff License                                                | [libtiff][]                              |      |
| Licence Libre du Québec – Permissive version 1.1               | [LiLiQ-P-1.1][]                          | Y    |
| Licence Libre du Québec – Réciprocité version 1.1              | [LiLiQ-R-1.1][]                          | Y    |
| Licence Libre du Québec – Réciprocité forte version 1.1        | [LiLiQ-Rplus-1.1][]                      | Y    |
| Lucent Public License Version 1.0                              | [LPL-1.0][]                              | Y    |
| Lucent Public License v1.02                                    | [LPL-1.02][]                             | Y    |
| LaTeX Project Public License v1.0                              | [LPPL-1.0][]                             |      |
| LaTeX Project Public License v1.1                              | [LPPL-1.1][]                             |      |
| LaTeX Project Public License v1.2                              | [LPPL-1.2][]                             |      |
| LaTeX Project Public License 1.3a                              | [LPPL-1.3a][]                            |      |
| LaTeX Project Public License v1.3c                             | [LPPL-1.3c][]                            | Y    |
| MakeIndex License                                              | [MakeIndex][]                            |      |
| MirOS Licence                                                  | [MirOS][]                                |      |
| MIT License                                                    | [MIT][]                                  | Y    |
| Enlightenment License (e16)                                    | [MIT-advertising][]                      |      |
| CMU License                                                    | [MIT-CMU][]                              |      |
| enna License                                                   | [MIT-enna][]                             |      |
| feh License                                                    | [MIT-feh][]                              |      |
| MIT +no-false-attribs license                                  | [MITNFA][]                               |      |
| Motosoto License                                               | [Motosoto][]                             |      |
| mpich2 License                                                 | [mpich2][]                               |      |
| Mozilla Public License 1.0                                     | [MPL-1.0][]                              | Y    |
| Mozilla Public License 1.1                                     | [MPL-1.1][]                              | Y    |
| Mozilla Public License 2.0                                     | [MPL-2.0][]                              | Y    |
| Mozilla Public License 2.0 (no copyleft exception)             | [MPL-2.0-no-copyleft-exception][]        | Y    |
| Microsoft Public License                                       | [MS-PL][]                                | Y    |
| Microsoft Reciprocal License                                   | [MS-RL][]                                | Y    |
| Matrix Template Library License                                | [MTLL][]                                 |      |
| Multics License                                                | [Multics][]                              |      |
| Mup License                                                    | [Mup][]                                  |      |
| NASA Open Source Agreement 1.3                                 | [NASA-1.3][]                             | Y    |
| Naumen Public License                                          | [Naumen][]                               | Y    |
| Net Boolean Public License v1                                  | [NBPL-1.0][]                             |      |
| University of Illinois/NCSA Open Source License                | [NCSA][]                                 | Y    |
| NetCDF license                                                 | [NetCDF][]                               |      |
| Newsletr License                                               | [Newsletr][]                             |      |
| Nethack General Public License                                 | [NGPL][]                                 | Y    |
| Norwgian License for Open Government Data                      | [NLOD-1.0][]                             |      |
| No Limit Public License                                        | [NLPL][]                                 |      |
| Nokia Open Source License                                      | [Nokia][]                                | Y    |
| Netizen Open Source License                                    | [NOSL][]                                 |      |
| Noweb License                                                  | [Noweb][]                                |      |
| Netscape Public License v1.0                                   | [NPL-1.0][]                              |      |
| Netscape Public License v1.1                                   | [NPL-1.1][]                              | Y    |
| Non-Profit Open Software License 3.0                           | [NPOSL-3.0][]                            | Y    |
| NRL License                                                    | [NRL][]                                  |      |
| NTP License                                                    | [NTP][]                                  | Y    |
| Nunit License                                                  | [Nunit][]                                |      |
| Open CASCADE Technology Public License                         | [OCCT-PL][]                              |      |
| OCLC Research Public License 2.0                               | [OCLC-2.0][]                             | Y    |
| ODC Open Database License v1.0                                 | [ODbL-1.0][]                             |      |
| SIL Open Font License 1.0                                      | [OFL-1.0][]                              |      |
| SIL Open Font License 1.1                                      | [OFL-1.1][]                              | Y    |
| Open Group Test Suite License                                  | [OGTSL][]                                | Y    |
| Open LDAP Public License v1.1                                  | [OLDAP-1.1][]                            |      |
| Open LDAP Public License v1.2                                  | [OLDAP-1.2][]                            |      |
| Open LDAP Public License v1.3                                  | [OLDAP-1.3][]                            |      |
| Open LDAP Public License v1.4                                  | [OLDAP-1.4][]                            |      |
| Open LDAP Public License v2.0 (or possibly 2.0A and 2.0B)      | [OLDAP-2.0][]                            |      |
| Open LDAP Public License v2.0.1                                | [OLDAP-2.0.1][]                          |      |
| Open LDAP Public License v2.1                                  | [OLDAP-2.1][]                            |      |
| Open LDAP Public License v2.2                                  | [OLDAP-2.2][]                            |      |
| Open LDAP Public License v2.2.1                                | [OLDAP-2.2.1][]                          |      |
| Open LDAP Public License 2.2.2                                 | [OLDAP-2.2.2][]                          |      |
| Open LDAP Public License v2.3                                  | [OLDAP-2.3][]                            |      |
| Open LDAP Public License v2.4                                  | [OLDAP-2.4][]                            |      |
| Open LDAP Public License v2.5                                  | [OLDAP-2.5][]                            |      |
| Open LDAP Public License v2.6                                  | [OLDAP-2.6][]                            |      |
| Open LDAP Public License v2.7                                  | [OLDAP-2.7][]                            |      |
| Open LDAP Public License v2.8                                  | [OLDAP-2.8][]                            |      |
| Open Market License                                            | [OML][]                                  |      |
| OpenSSL License                                                | [OpenSSL][]                              |      |
| Open Public License v1.0                                       | [OPL-1.0][]                              |      |
| OSET Public License version 2.1                                | [OSET-PL-2.1][]                          | Y    |
| Open Software License 1.0                                      | [OSL-1.0][]                              | Y    |
| Open Software License 1.1                                      | [OSL-1.1][]                              |      |
| Open Software License 2.0                                      | [OSL-2.0][]                              | Y    |
| Open Software License 2.1                                      | [OSL-2.1][]                              | Y    |
| Open Software License 3.0                                      | [OSL-3.0][]                              | Y    |
| ODC Public Domain Dedication & License 1.0                     | [PDDL-1.0][]                             |      |
| PHP License v3.0                                               | [PHP-3.0][]                              | Y    |
| PHP License v3.01                                              | [PHP-3.01][]                             |      |
| Plexus Classworlds License                                     | [Plexus][]                               |      |
| PostgreSQL License                                             | [PostgreSQL][]                           | Y    |
| psfrag License                                                 | [psfrag][]                               |      |
| psutils License                                                | [psutils][]                              |      |
| Python License 2.0                                             | [Python-2.0][]                           | Y    |
| Qhull License                                                  | [Qhull][]                                |      |
| Q Public License 1.0                                           | [QPL-1.0][]                              | Y    |
| Rdisc License                                                  | [Rdisc][]                                |      |
| Red Hat eCos Public License v1.1                               | [RHeCos-1.1][]                           |      |
| Reciprocal Public License 1.1                                  | [RPL-1.1][]                              | Y    |
| Reciprocal Public License 1.5                                  | [RPL-1.5][]                              | Y    |
| RealNetworks Public Source License v1.0                        | [RPSL-1.0][]                             | Y    |
| RSA Message-Digest License                                     | [RSA-MD][]                               |      |
| Ricoh Source Code Public License                               | [RSCPL][]                                | Y    |
| Ruby License                                                   | [Ruby][]                                 |      |
| Sax Public Domain Notice                                       | [SAX-PD][]                               |      |
| Saxpath License                                                | [Saxpath][]                              |      |
| SCEA Shared Source License                                     | [SCEA][]                                 |      |
| Sendmail License                                               | [Sendmail][]                             |      |
| SGI Free Software License B v1.0                               | [SGI-B-1.0][]                            |      |
| SGI Free Software License B v1.1                               | [SGI-B-1.1][]                            |      |
| SGI Free Software License B v2.0                               | [SGI-B-2.0][]                            |      |
| Simple Public License 2.0                                      | [SimPL-2.0][]                            | Y    |
| Sun Industry Standards Source License v1.1                     | [SISSL][]                                | Y    |
| Sun Industry Standards Source License v1.2                     | [SISSL-1.2][]                            |      |
| Sleepycat License                                              | [Sleepycat][]                            | Y    |
| Standard ML of New Jersey License                              | [SMLNJ][]                                |      |
| Secure Messaging Protocol Public License                       | [SMPPL][]                                |      |
| SNIA Public License 1.1                                        | [SNIA][]                                 |      |
| Spencer License 86                                             | [Spencer-86][]                           |      |
| Spencer License 94                                             | [Spencer-94][]                           |      |
| Spencer License 99                                             | [Spencer-99][]                           |      |
| Sun Public License v1.0                                        | [SPL-1.0][]                              | Y    |
| SugarCRM Public License v1.1.3                                 | [SugarCRM-1.1.3][]                       |      |
| Scheme Widget Library (SWL) Software License Agreement         | [SWL][]                                  |      |
| TCL/TK License                                                 | [TCL][]                                  |      |
| TMate Open Source License                                      | [TMate][]                                |      |
| TORQUE v2.5+ Software License v1.1                             | [TORQUE-1.1][]                           |      |
| Trusster Open Source License                                   | [TOSL][]                                 |      |
| Unicode Terms of Use                                           | [Unicode-TOU][]                          |      |
| The Unlicense                                                  | [Unlicense][]                            |      |
| Universal Permissive Licenses v1.0                             | [UPL-1.0][]                              | Y    |
| Vim License                                                    | [Vim][]                                  |      |
| VOSTROM Public License for Open Source                         | [VOSTROM][]                              |      |
| Vovida Software License v1.0                                   | [VSL-1.0][]                              | Y    |
| W3C Software Notice and License (2002-12-31)                   | [W3C][]                                  | Y    |
| W3C Software Notice and License (1998-07-20)                   | [W3C-19980720][]                         |      |
| Sybase Open Watcom Public License 1.0                          | [Watcom-1.0][]                           | Y    |
| Wsuipa License                                                 | [Wsuipa][]                               |      |
| Do What The F*ck You Want To Public License                    | [WTFPL][]                                |      |
| X11 License                                                    | [X11][]                                  |      |
| Xerox License                                                  | [Xerox][]                                |      |
| XFree86 License 1.1                                            | [XFree86-1.1][]                          |      |
| xinetd License                                                 | [xinetd][]                               |      |
| X.Net License                                                  | [Xnet][]                                 | Y    |
| XPP License                                                    | [xpp][]                                  |      |
| XSkat License                                                  | [XSkat][]                                |      |
| Yahoo! Public License v1.0                                     | [YPL-1.0][]                              |      |
| Yahoo! Public License v1.1                                     | [YPL-1.1][]                              |      |
| Zed License                                                    | [Zed][]                                  |      |
| Zend License v2.0                                              | [Zend-2.0][]                             |      |
| Zimbra Public License v1.3                                     | [Zimbra-1.3][]                           |      |
| Zimbra Public License v1.4                                     | [Zimbra-1.4][]                           |      |
| zlib License                                                   | [Zlib][]                                 | Y    |
| zlib/libpng License with Acknowledgement                       | [zlib-acknowledgement][]                 |      |
| Zope Public License 1.1                                        | [ZPL-1.1][]                              |      |
| Zope Public License 2.0                                        | [ZPL-2.0][]                              | Y    |
| Zope Public License 2.1                                        | [ZPL-2.1][]                              |      |

## I.2 Exceptions List <a name="I.2"></a>

| Full Name of Exception                | SPDX LicenseException         |
|---------------------------------------|-------------------------------|
| 389 Directory Server Exception        | [389-exception][]             |
| Autoconf exception 2.0                | [Autoconf-exception-2.0][]    |
| Autoconf exception 3.0                | [Autoconf-exception-3.0][]    |
| Bison exception 2.2                   | [Bison-exception-2.2][]       |
| Classpath exception 2.0               | [Classpath-exception-2.0][]   |
| CLISP exception 2.0                   | [CLISP-exception-2.0][]       |
| DigiRule FOSS License Exception       | [DigiRule-FOSS-exception][]   |
| eCos exception 2.0                    | [eCos-exception-2.0][]        |
| Fawkes Runtime Exception              | [Fawkes-Runtime-exception][]  |
| FLTK exception                        | [FLTK-exception][]            |
| Font exception 2.0                    | [Font-exception-2.0][]        |
| FreeRTOS Exception 2.0                | [freertos-exception-2.0][]    |
| GCC Runtime Library exception 2.0     | [GCC-exception-2.0][]         |
| GCC Runtime Library exception 3.1     | [GCC-exception-3.1][]         |
| GNU JavaMail exception                | [gnu-javamail-exception][]    |
| i2p GPL+Java Exception                | [i2p-gpl-java-exception][]    |
| Libtool Exception                     | [Libtool-exception][]         |
| LZMA exception                        | [LZMA-exception][]            |
| Macros and Inline Functions Exception | [mif-exception][]             |
| Nokia Qt LGPL exception 1.1           | [Nokia-Qt-exception-1.1][]    |
| Open CASCADE Exception 1.0            | [OCCT-exception-1.0][]        |
| OpenVPN OpenSSL Exception             | [openvpn-openssl-exception][] |
| Qwt exception 1.0                     | [Qwt-exception-1.0][]         |
| U-Boot exception 2.0                  | [u-boot-exception-2.0][]      |
| WxWindows Library Exception 3.1       | [WxWindows-exception-3.1][]   |

## I.3 Deprecated Licenses <a name="I.3"></a>

| Full Name of License                                            | Deprecated SPDX License Identifier     |
|-----------------------------------------------------------------|----------------------------------------|
| eCos license version 2.0                                        | [eCos-2.0][]                           |
| GNU General Public License v1.0 or later                        | [GPL-1.0+][]                           |
| GNU General Public License v2.0 or later                        | [GPL-2.0+][]                           |
| GNU General Public License v2.0 w/Autoconf exception            | [GPL-2.0-with-autoconf-exception][]    |
| GNU General Public License v2.0 w/Bison exception               | [GPL-2.0-with-bison-exception][]       |
| GNU General Public License v2.0 w/Classpath exception           | [GPL-2.0-with-classpath-exception][]   |
| GNU General Public License v2.0 w/Font exception                | [GPL-2.0-with-font-exception][]        |
| GNU General Public License v2.0 w/GCC Runtime Library exception | [GPL-2.0-with-GCC-exception][]         |
| GNU General Public License v3.0 or later                        | [GPL-3.0+][]                           |
| GNU General Public License v3.0 w/Autoconf exception            | [GPL-3.0-with-autoconf-exception][]    |
| GNU General Public License v3.0 w/GCC Runtime Library exception | [GPL-3.0-with-GCC-exception][]         |
| GNU Lesser General Public License v2.1 or later                 | [LGPL-2.1+][]                          |
| GNU Lesser General Public License v3.0 or later                 | [LGPL-3.0+][]                          |
| GNU Library General Public License v2 or later                  | [LGPL-2.0+][]                          |
| Standard ML of New Jersey License                               | [StandardML-NJ][]                      |
| wxWindows Library License                                       | [WXwindows][]                          |

[0BSD]: https://spdx.org/licenses/0BSD.html
[AAL]: https://spdx.org/licenses/AAL.html
[Abstyles]: https://spdx.org/licenses/Abstyles.html
[Adobe-2006]: https://spdx.org/licenses/Adobe-2006.html
[Adobe-Glyph]: https://spdx.org/licenses/Adobe-Glyph.html
[ADSL]: https://spdx.org/licenses/ADSL.html
[AFL-1.1]: https://spdx.org/licenses/AFL-1.1.html
[AFL-1.2]: https://spdx.org/licenses/AFL-1.2.html
[AFL-2.0]: https://spdx.org/licenses/AFL-2.0.html
[AFL-2.1]: https://spdx.org/licenses/AFL-2.1.html
[AFL-3.0]: https://spdx.org/licenses/AFL-3.0.html
[Afmparse]: https://spdx.org/licenses/Afmparse.html
[AGPL-1.0]: https://spdx.org/licenses/AGPL-1.0.html
[AGPL-3.0]: https://spdx.org/licenses/AGPL-3.0.html
[Aladdin]: https://spdx.org/licenses/Aladdin.html
[AMDPLPA]: https://spdx.org/licenses/AMDPLPA.html
[AML]: https://spdx.org/licenses/AML.html
[AMPAS]: https://spdx.org/licenses/AMPAS.html
[ANTLR-PD]: https://spdx.org/licenses/ANTLR-PD.html
[Apache-1.0]: https://spdx.org/licenses/Apache-1.0.html
[Apache-1.1]: https://spdx.org/licenses/Apache-1.1.html
[Apache-2.0]: https://spdx.org/licenses/Apache-2.0.html
[APAFML]: https://spdx.org/licenses/APAFML.html
[APL-1.0]: https://spdx.org/licenses/APL-1.0.html
[APSL-1.0]: https://spdx.org/licenses/APSL-1.0.html
[APSL-1.1]: https://spdx.org/licenses/APSL-1.1.html
[APSL-1.2]: https://spdx.org/licenses/APSL-1.2.html
[APSL-2.0]: https://spdx.org/licenses/APSL-2.0.html
[Artistic-1.0-cl8]: https://spdx.org/licenses/Artistic-1.0-cl8.html
[Artistic-1.0-Perl]: https://spdx.org/licenses/Artistic-1.0-Perl.html
[Artistic-1.0]: https://spdx.org/licenses/Artistic-1.0.html
[Artistic-2.0]: https://spdx.org/licenses/Artistic-2.0.html
[Bahyph]: https://spdx.org/licenses/Bahyph.html
[Barr]: https://spdx.org/licenses/Barr.html
[Beerware]: https://spdx.org/licenses/Beerware.html
[BitTorrent-1.0]: https://spdx.org/licenses/BitTorrent-1.0.html
[BitTorrent-1.1]: https://spdx.org/licenses/BitTorrent-1.1.html
[Borceux]: https://spdx.org/licenses/Borceux.html
[BSD-2-Clause-FreeBSD]: https://spdx.org/licenses/BSD-2-Clause-FreeBSD.html
[BSD-2-Clause-NetBSD]: https://spdx.org/licenses/BSD-2-Clause-NetBSD.html
[BSD-2-Clause]: https://spdx.org/licenses/BSD-2-Clause.html
[BSD-3-Clause-Attribution]: https://spdx.org/licenses/BSD-3-Clause-Attribution.html
[BSD-3-Clause-Clear]: https://spdx.org/licenses/BSD-3-Clause-Clear.html
[BSD-3-Clause-LBNL]: https://spdx.org/licenses/BSD-3-Clause-LBNL.html
[BSD-3-Clause-No-Nuclear-License-2014]: https://spdx.org/licenses/BSD-3-Clause-No-Nuclear-License-2014.html
[BSD-3-Clause-No-Nuclear-License]: https://spdx.org/licenses/BSD-3-Clause-No-Nuclear-License.html
[BSD-3-Clause-No-Nuclear-Warranty]: https://spdx.org/licenses/BSD-3-Clause-No-Nuclear-Warranty.html
[BSD-3-Clause]: https://spdx.org/licenses/BSD-3-Clause.html
[BSD-4-Clause-UC]: https://spdx.org/licenses/BSD-4-Clause-UC.html
[BSD-4-Clause]: https://spdx.org/licenses/BSD-4-Clause.html
[BSD-Protection]: https://spdx.org/licenses/BSD-Protection.html
[BSD-Source-Code]: https://spdx.org/licenses/BSD-Source-Code.html
[BSL-1.0]: https://spdx.org/licenses/BSL-1.0.html
[bzip2-1.0.5]: https://spdx.org/licenses/bzip2-1.0.5.html
[bzip2-1.0.6]: https://spdx.org/licenses/bzip2-1.0.6.html
[Caldera]: https://spdx.org/licenses/Caldera.html
[CATOSL-1.1]: https://spdx.org/licenses/CATOSL-1.1.html
[CC-BY-1.0]: https://spdx.org/licenses/CC-BY-1.0.html
[CC-BY-2.0]: https://spdx.org/licenses/CC-BY-2.0.html
[CC-BY-2.5]: https://spdx.org/licenses/CC-BY-2.5.html
[CC-BY-3.0]: https://spdx.org/licenses/CC-BY-3.0.html
[CC-BY-4.0]: https://spdx.org/licenses/CC-BY-4.0.html
[CC-BY-NC-1.0]: https://spdx.org/licenses/CC-BY-NC-1.0.html
[CC-BY-NC-2.0]: https://spdx.org/licenses/CC-BY-NC-2.0.html
[CC-BY-NC-2.5]: https://spdx.org/licenses/CC-BY-NC-2.5.html
[CC-BY-NC-3.0]: https://spdx.org/licenses/CC-BY-NC-3.0.html
[CC-BY-NC-4.0]: https://spdx.org/licenses/CC-BY-NC-4.0.html
[CC-BY-NC-ND-1.0]: https://spdx.org/licenses/CC-BY-NC-ND-1.0.html
[CC-BY-NC-ND-2.0]: https://spdx.org/licenses/CC-BY-NC-ND-2.0.html
[CC-BY-NC-ND-2.5]: https://spdx.org/licenses/CC-BY-NC-ND-2.5.html
[CC-BY-NC-ND-3.0]: https://spdx.org/licenses/CC-BY-NC-ND-3.0.html
[CC-BY-NC-ND-4.0]: https://spdx.org/licenses/CC-BY-NC-ND-4.0.html
[CC-BY-NC-SA-1.0]: https://spdx.org/licenses/CC-BY-NC-SA-1.0.html
[CC-BY-NC-SA-2.0]: https://spdx.org/licenses/CC-BY-NC-SA-2.0.html
[CC-BY-NC-SA-2.5]: https://spdx.org/licenses/CC-BY-NC-SA-2.5.html
[CC-BY-NC-SA-3.0]: https://spdx.org/licenses/CC-BY-NC-SA-3.0.html
[CC-BY-NC-SA-4.0]: https://spdx.org/licenses/CC-BY-NC-SA-4.0.html
[CC-BY-ND-1.0]: https://spdx.org/licenses/CC-BY-ND-1.0.html
[CC-BY-ND-2.0]: https://spdx.org/licenses/CC-BY-ND-2.0.html
[CC-BY-ND-2.5]: https://spdx.org/licenses/CC-BY-ND-2.5.html
[CC-BY-ND-3.0]: https://spdx.org/licenses/CC-BY-ND-3.0.html
[CC-BY-ND-4.0]: https://spdx.org/licenses/CC-BY-ND-4.0.html
[CC-BY-SA-1.0]: https://spdx.org/licenses/CC-BY-SA-1.0.html
[CC-BY-SA-2.0]: https://spdx.org/licenses/CC-BY-SA-2.0.html
[CC-BY-SA-2.5]: https://spdx.org/licenses/CC-BY-SA-2.5.html
[CC-BY-SA-3.0]: https://spdx.org/licenses/CC-BY-SA-3.0.html
[CC-BY-SA-4.0]: https://spdx.org/licenses/CC-BY-SA-4.0.html
[CC0-1.0]: https://spdx.org/licenses/CC0-1.0.html
[CDDL-1.0]: https://spdx.org/licenses/CDDL-1.0.html
[CDDL-1.1]: https://spdx.org/licenses/CDDL-1.1.html
[CECILL-1.0]: https://spdx.org/licenses/CECILL-1.0.html
[CECILL-1.1]: https://spdx.org/licenses/CECILL-1.1.html
[CECILL-2.0]: https://spdx.org/licenses/CECILL-2.0.html
[CECILL-2.1]: https://spdx.org/licenses/CECILL-2.1.html
[CECILL-B]: https://spdx.org/licenses/CECILL-B.html
[CECILL-C]: https://spdx.org/licenses/CECILL-C.html
[ClArtistic]: https://spdx.org/licenses/ClArtistic.html
[CNRI-Jython]: https://spdx.org/licenses/CNRI-Jython.html
[CNRI-Python-GPL-Compatible]: https://spdx.org/licenses/CNRI-Python-GPL-Compatible.html
[CNRI-Python]: https://spdx.org/licenses/CNRI-Python.html
[Condor-1.1]: https://spdx.org/licenses/Condor-1.1.html
[CPAL-1.0]: https://spdx.org/licenses/CPAL-1.0.html
[CPL-1.0]: https://spdx.org/licenses/CPL-1.0.html
[CPOL-1.02]: https://spdx.org/licenses/CPOL-1.02.html
[Crossword]: https://spdx.org/licenses/Crossword.html
[CrystalStacker]: https://spdx.org/licenses/CrystalStacker.html
[CUA-OPL-1.0]: https://spdx.org/licenses/CUA-OPL-1.0.html
[Cube]: https://spdx.org/licenses/Cube.html
[curl]: https://spdx.org/licenses/curl.html
[D-FSL-1.0]: https://spdx.org/licenses/D-FSL-1.0.html
[diffmark]: https://spdx.org/licenses/diffmark.html
[DOC]: https://spdx.org/licenses/DOC.html
[Dotseqn]: https://spdx.org/licenses/Dotseqn.html
[DSDP]: https://spdx.org/licenses/DSDP.html
[dvipdfm]: https://spdx.org/licenses/dvipdfm.html
[ECL-1.0]: https://spdx.org/licenses/ECL-1.0.html
[ECL-2.0]: https://spdx.org/licenses/ECL-2.0.html
[EFL-1.0]: https://spdx.org/licenses/EFL-1.0.html
[EFL-2.0]: https://spdx.org/licenses/EFL-2.0.html
[eGenix]: https://spdx.org/licenses/eGenix.html
[Entessa]: https://spdx.org/licenses/Entessa.html
[EPL-1.0]: https://spdx.org/licenses/EPL-1.0.html
[ErlPL-1.1]: https://spdx.org/licenses/ErlPL-1.1.html
[EUDatagrid]: https://spdx.org/licenses/EUDatagrid.html
[EUPL-1.0]: https://spdx.org/licenses/EUPL-1.0.html
[EUPL-1.1]: https://spdx.org/licenses/EUPL-1.1.html
[Eurosym]: https://spdx.org/licenses/Eurosym.html
[Fair]: https://spdx.org/licenses/Fair.html
[Frameworx-1.0]: https://spdx.org/licenses/Frameworx-1.0.html
[FreeImage]: https://spdx.org/licenses/FreeImage.html
[FSFAP]: https://spdx.org/licenses/FSFAP.html
[FSFUL]: https://spdx.org/licenses/FSFUL.html
[FSFULLR]: https://spdx.org/licenses/FSFULLR.html
[FTL]: https://spdx.org/licenses/FTL.html
[GFDL-1.1]: https://spdx.org/licenses/GFDL-1.1.html
[GFDL-1.2]: https://spdx.org/licenses/GFDL-1.2.html
[GFDL-1.3]: https://spdx.org/licenses/GFDL-1.3.html
[Giftware]: https://spdx.org/licenses/Giftware.html
[GL2PS]: https://spdx.org/licenses/GL2PS.html
[Glide]: https://spdx.org/licenses/Glide.html
[Glulxe]: https://spdx.org/licenses/Glulxe.html
[gnuplot]: https://spdx.org/licenses/gnuplot.html
[GPL-1.0]: https://spdx.org/licenses/GPL-1.0.html
[GPL-2.0]: https://spdx.org/licenses/GPL-2.0.html
[GPL-3.0]: https://spdx.org/licenses/GPL-3.0.html
[gSOAP-1.3b]: https://spdx.org/licenses/gSOAP-1.3b.html
[HaskellReport]: https://spdx.org/licenses/HaskellReport.html
[HPND]: https://spdx.org/licenses/HPND.html
[IBM-pibs]: https://spdx.org/licenses/IBM-pibs.html
[ICU]: https://spdx.org/licenses/ICU.html
[IJG]: https://spdx.org/licenses/IJG.html
[ImageMagick]: https://spdx.org/licenses/ImageMagick.html
[iMatix]: https://spdx.org/licenses/iMatix.html
[Imlib2]: https://spdx.org/licenses/Imlib2.html
[Info-ZIP]: https://spdx.org/licenses/Info-ZIP.html
[Intel-ACPI]: https://spdx.org/licenses/Intel-ACPI.html
[Intel]: https://spdx.org/licenses/Intel.html
[Interbase-1.0]: https://spdx.org/licenses/Interbase-1.0.html
[IPA]: https://spdx.org/licenses/IPA.html
[IPL-1.0]: https://spdx.org/licenses/IPL-1.0.html
[ISC]: https://spdx.org/licenses/ISC.html
[JasPer-2.0]: https://spdx.org/licenses/JasPer-2.0.html
[JSON]: https://spdx.org/licenses/JSON.html
[LAL-1.2]: https://spdx.org/licenses/LAL-1.2.html
[LAL-1.3]: https://spdx.org/licenses/LAL-1.3.html
[Latex2e]: https://spdx.org/licenses/Latex2e.html
[Leptonica]: https://spdx.org/licenses/Leptonica.html
[LGPL-2.0]: https://spdx.org/licenses/LGPL-2.0.html
[LGPL-2.1]: https://spdx.org/licenses/LGPL-2.1.html
[LGPL-3.0]: https://spdx.org/licenses/LGPL-3.0.html
[LGPLLR]: https://spdx.org/licenses/LGPLLR.html
[Libpng]: https://spdx.org/licenses/Libpng.html
[libtiff]: https://spdx.org/licenses/libtiff.html
[LiLiQ-P-1.1]: https://spdx.org/licenses/LiLiQ-P-1.1.html
[LiLiQ-R-1.1]: https://spdx.org/licenses/LiLiQ-R-1.1.html
[LiLiQ-Rplus-1.1]: https://spdx.org/licenses/LiLiQ-Rplus-1.1.html
[LPL-1.0]: https://spdx.org/licenses/LPL-1.0.html
[LPL-1.02]: https://spdx.org/licenses/LPL-1.02.html
[LPPL-1.0]: https://spdx.org/licenses/LPPL-1.0.html
[LPPL-1.1]: https://spdx.org/licenses/LPPL-1.1.html
[LPPL-1.2]: https://spdx.org/licenses/LPPL-1.2.html
[LPPL-1.3a]: https://spdx.org/licenses/LPPL-1.3a.html
[LPPL-1.3c]: https://spdx.org/licenses/LPPL-1.3c.html
[MakeIndex]: https://spdx.org/licenses/MakeIndex.html
[MirOS]: https://spdx.org/licenses/MirOS.html
[MIT-advertising]: https://spdx.org/licenses/MIT-advertising.html
[MIT-CMU]: https://spdx.org/licenses/MIT-CMU.html
[MIT-enna]: https://spdx.org/licenses/MIT-enna.html
[MIT-feh]: https://spdx.org/licenses/MIT-feh.html
[MIT]: https://spdx.org/licenses/MIT.html
[MITNFA]: https://spdx.org/licenses/MITNFA.html
[Motosoto]: https://spdx.org/licenses/Motosoto.html
[mpich2]: https://spdx.org/licenses/mpich2.html
[MPL-1.0]: https://spdx.org/licenses/MPL-1.0.html
[MPL-1.1]: https://spdx.org/licenses/MPL-1.1.html
[MPL-2.0-no-copyleft-exception]: https://spdx.org/licenses/MPL-2.0-no-copyleft-exception.html
[MPL-2.0]: https://spdx.org/licenses/MPL-2.0.html
[MS-PL]: https://spdx.org/licenses/MS-PL.html
[MS-RL]: https://spdx.org/licenses/MS-RL.html
[MTLL]: https://spdx.org/licenses/MTLL.html
[Multics]: https://spdx.org/licenses/Multics.html
[Mup]: https://spdx.org/licenses/Mup.html
[NASA-1.3]: https://spdx.org/licenses/NASA-1.3.html
[Naumen]: https://spdx.org/licenses/Naumen.html
[NBPL-1.0]: https://spdx.org/licenses/NBPL-1.0.html
[NCSA]: https://spdx.org/licenses/NCSA.html
[NetCDF]: https://spdx.org/licenses/NetCDF.html
[Newsletr]: https://spdx.org/licenses/Newsletr.html
[NGPL]: https://spdx.org/licenses/NGPL.html
[NLOD-1.0]: https://spdx.org/licenses/NLOD-1.0.html
[NLPL]: https://spdx.org/licenses/NLPL.html
[Nokia]: https://spdx.org/licenses/Nokia.html
[NOSL]: https://spdx.org/licenses/NOSL.html
[Noweb]: https://spdx.org/licenses/Noweb.html
[NPL-1.0]: https://spdx.org/licenses/NPL-1.0.html
[NPL-1.1]: https://spdx.org/licenses/NPL-1.1.html
[NPOSL-3.0]: https://spdx.org/licenses/NPOSL-3.0.html
[NRL]: https://spdx.org/licenses/NRL.html
[NTP]: https://spdx.org/licenses/NTP.html
[Nunit]: https://spdx.org/licenses/Nunit.html
[OCCT-PL]: https://spdx.org/licenses/OCCT-PL.html
[OCLC-2.0]: https://spdx.org/licenses/OCLC-2.0.html
[ODbL-1.0]: https://spdx.org/licenses/ODbL-1.0.html
[OFL-1.0]: https://spdx.org/licenses/OFL-1.0.html
[OFL-1.1]: https://spdx.org/licenses/OFL-1.1.html
[OGTSL]: https://spdx.org/licenses/OGTSL.html
[OLDAP-1.1]: https://spdx.org/licenses/OLDAP-1.1.html
[OLDAP-1.2]: https://spdx.org/licenses/OLDAP-1.2.html
[OLDAP-1.3]: https://spdx.org/licenses/OLDAP-1.3.html
[OLDAP-1.4]: https://spdx.org/licenses/OLDAP-1.4.html
[OLDAP-2.0.1]: https://spdx.org/licenses/OLDAP-2.0.1.html
[OLDAP-2.0]: https://spdx.org/licenses/OLDAP-2.0.html
[OLDAP-2.1]: https://spdx.org/licenses/OLDAP-2.1.html
[OLDAP-2.2.1]: https://spdx.org/licenses/OLDAP-2.2.1.html
[OLDAP-2.2.2]: https://spdx.org/licenses/OLDAP-2.2.2.html
[OLDAP-2.2]: https://spdx.org/licenses/OLDAP-2.2.html
[OLDAP-2.3]: https://spdx.org/licenses/OLDAP-2.3.html
[OLDAP-2.4]: https://spdx.org/licenses/OLDAP-2.4.html
[OLDAP-2.5]: https://spdx.org/licenses/OLDAP-2.5.html
[OLDAP-2.6]: https://spdx.org/licenses/OLDAP-2.6.html
[OLDAP-2.7]: https://spdx.org/licenses/OLDAP-2.7.html
[OLDAP-2.8]: https://spdx.org/licenses/OLDAP-2.8.html
[OML]: https://spdx.org/licenses/OML.html
[OpenSSL]: https://spdx.org/licenses/OpenSSL.html
[OPL-1.0]: https://spdx.org/licenses/OPL-1.0.html
[OSET-PL-2.1]: https://spdx.org/licenses/OSET-PL-2.1.html
[OSL-1.0]: https://spdx.org/licenses/OSL-1.0.html
[OSL-1.1]: https://spdx.org/licenses/OSL-1.1.html
[OSL-2.0]: https://spdx.org/licenses/OSL-2.0.html
[OSL-2.1]: https://spdx.org/licenses/OSL-2.1.html
[OSL-3.0]: https://spdx.org/licenses/OSL-3.0.html
[PDDL-1.0]: https://spdx.org/licenses/PDDL-1.0.html
[PHP-3.0]: https://spdx.org/licenses/PHP-3.0.html
[PHP-3.01]: https://spdx.org/licenses/PHP-3.01.html
[Plexus]: https://spdx.org/licenses/Plexus.html
[PostgreSQL]: https://spdx.org/licenses/PostgreSQL.html
[psfrag]: https://spdx.org/licenses/psfrag.html
[psutils]: https://spdx.org/licenses/psutils.html
[Python-2.0]: https://spdx.org/licenses/Python-2.0.html
[Qhull]: https://spdx.org/licenses/Qhull.html
[QPL-1.0]: https://spdx.org/licenses/QPL-1.0.html
[Rdisc]: https://spdx.org/licenses/Rdisc.html
[README]: https://spdx.org/licenses/README.html
[RHeCos-1.1]: https://spdx.org/licenses/RHeCos-1.1.html
[RPL-1.1]: https://spdx.org/licenses/RPL-1.1.html
[RPL-1.5]: https://spdx.org/licenses/RPL-1.5.html
[RPSL-1.0]: https://spdx.org/licenses/RPSL-1.0.html
[RSA-MD]: https://spdx.org/licenses/RSA-MD.html
[RSCPL]: https://spdx.org/licenses/RSCPL.html
[Ruby]: https://spdx.org/licenses/Ruby.html
[SAX-PD]: https://spdx.org/licenses/SAX-PD.html
[Saxpath]: https://spdx.org/licenses/Saxpath.html
[SCEA]: https://spdx.org/licenses/SCEA.html
[Sendmail]: https://spdx.org/licenses/Sendmail.html
[SGI-B-1.0]: https://spdx.org/licenses/SGI-B-1.0.html
[SGI-B-1.1]: https://spdx.org/licenses/SGI-B-1.1.html
[SGI-B-2.0]: https://spdx.org/licenses/SGI-B-2.0.html
[SimPL-2.0]: https://spdx.org/licenses/SimPL-2.0.html
[SISSL-1.2]: https://spdx.org/licenses/SISSL-1.2.html
[SISSL]: https://spdx.org/licenses/SISSL.html
[Sleepycat]: https://spdx.org/licenses/Sleepycat.html
[SMLNJ]: https://spdx.org/licenses/SMLNJ.html
[SMPPL]: https://spdx.org/licenses/SMPPL.html
[SNIA]: https://spdx.org/licenses/SNIA.html
[Spencer-86]: https://spdx.org/licenses/Spencer-86.html
[Spencer-94]: https://spdx.org/licenses/Spencer-94.html
[Spencer-99]: https://spdx.org/licenses/Spencer-99.html
[SPL-1.0]: https://spdx.org/licenses/SPL-1.0.html
[SugarCRM-1.1.3]: https://spdx.org/licenses/SugarCRM-1.1.3.html
[SWL]: https://spdx.org/licenses/SWL.html
[TCL]: https://spdx.org/licenses/TCL.html
[TMate]: https://spdx.org/licenses/TMate.html
[TORQUE-1.1]: https://spdx.org/licenses/TORQUE-1.1.html
[TOSL]: https://spdx.org/licenses/TOSL.html
[Unicode-TOU]: https://spdx.org/licenses/Unicode-TOU.html
[Unlicense]: https://spdx.org/licenses/Unlicense.html
[UPL-1.0]: https://spdx.org/licenses/UPL-1.0.html
[Vim]: https://spdx.org/licenses/Vim.html
[VOSTROM]: https://spdx.org/licenses/VOSTROM.html
[VSL-1.0]: https://spdx.org/licenses/VSL-1.0.html
[W3C-19980720]: https://spdx.org/licenses/W3C-19980720.html
[W3C]: https://spdx.org/licenses/W3C.html
[Watcom-1.0]: https://spdx.org/licenses/Watcom-1.0.html
[Wsuipa]: https://spdx.org/licenses/Wsuipa.html
[WTFPL]: https://spdx.org/licenses/WTFPL.html
[X11]: https://spdx.org/licenses/X11.html
[Xerox]: https://spdx.org/licenses/Xerox.html
[XFree86-1.1]: https://spdx.org/licenses/XFree86-1.1.html
[xinetd]: https://spdx.org/licenses/xinetd.html
[Xnet]: https://spdx.org/licenses/Xnet.html
[xpp]: https://spdx.org/licenses/xpp.html
[XSkat]: https://spdx.org/licenses/XSkat.html
[YPL-1.0]: https://spdx.org/licenses/YPL-1.0.html
[YPL-1.1]: https://spdx.org/licenses/YPL-1.1.html
[Zed]: https://spdx.org/licenses/Zed.html
[Zend-2.0]: https://spdx.org/licenses/Zend-2.0.html
[Zimbra-1.3]: https://spdx.org/licenses/Zimbra-1.3.html
[Zimbra-1.4]: https://spdx.org/licenses/Zimbra-1.4.html
[zlib-acknowledgement]: https://spdx.org/licenses/zlib-acknowledgement.html
[Zlib]: https://spdx.org/licenses/Zlib.html
[ZPL-1.1]: https://spdx.org/licenses/ZPL-1.1.html
[ZPL-2.0]: https://spdx.org/licenses/ZPL-2.0.html
[ZPL-2.1]: https://spdx.org/licenses/ZPL-2.1.html
[389-exception]: https://spdx.org/licenses/389-exception.html
[Autoconf-exception-2.0]: https://spdx.org/licenses/Autoconf-exception-2.0.html
[Autoconf-exception-3.0]: https://spdx.org/licenses/Autoconf-exception-3.0.html
[Bison-exception-2.2]: https://spdx.org/licenses/Bison-exception-2.2.html
[Classpath-exception-2.0]: https://spdx.org/licenses/Classpath-exception-2.0.html
[CLISP-exception-2.0]: https://spdx.org/licenses/CLISP-exception-2.0.html
[DigiRule-FOSS-exception]: https://spdx.org/licenses/DigiRule-FOSS-exception.html
[eCos-exception-2.0]: https://spdx.org/licenses/eCos-exception-2.0.html
[Fawkes-Runtime-exception]: https://spdx.org/licenses/Fawkes-Runtime-exception.html
[FLTK-exception]: https://spdx.org/licenses/FLTK-exception.html
[Font-exception-2.0]: https://spdx.org/licenses/Font-exception-2.0.html
[freertos-exception-2.0]: https://spdx.org/licenses/freertos-exception-2.0.html
[GCC-exception-2.0]: https://spdx.org/licenses/GCC-exception-2.0.html
[GCC-exception-3.1]: https://spdx.org/licenses/GCC-exception-3.1.html
[gnu-javamail-exception]: https://spdx.org/licenses/gnu-javamail-exception.html
[i2p-gpl-java-exception]: https://spdx.org/licenses/i2p-gpl-java-exception.html
[Libtool-exception]: https://spdx.org/licenses/Libtool-exception.html
[LZMA-exception]: https://spdx.org/licenses/LZMA-exception.html
[mif-exception]: https://spdx.org/licenses/mif-exception.html
[Nokia-Qt-exception-1.1]: https://spdx.org/licenses/Nokia-Qt-exception-1.1.html
[OCCT-exception-1.0]: https://spdx.org/licenses/OCCT-exception-1.0.html
[openvpn-openssl-exception]: https://spdx.org/licenses/openvpn-openssl-exception.html
[Qwt-exception-1.0]: https://spdx.org/licenses/Qwt-exception-1.0.html
[u-boot-exception-2.0]: https://spdx.org/licenses/u-boot-exception-2.0.html
[WxWindows-exception-3.1]: https://spdx.org/licenses/WxWindows-exception-3.1.html

[eCos-2.0]: https://spdx.org/licenses/eCos-2.0.html
[GPL-1.0+]: https://spdx.org/licenses/GPL-1.0+.html
[GPL-2.0+]: https://spdx.org/licenses/GPL-2.0+.html
[GPL-2.0-with-autoconf-exception]: https://spdx.org/licenses/GPL-2.0-with-autoconf-exception.html
[GPL-2.0-with-bison-exception]: https://spdx.org/licenses/GPL-2.0-with-bison-exception.html
[GPL-2.0-with-classpath-exception]: https://spdx.org/licenses/GPL-2.0-with-classpath-exception.html
[GPL-2.0-with-font-exception]: https://spdx.org/licenses/GPL-2.0-with-font-exception.html
[GPL-2.0-with-GCC-exception]: https://spdx.org/licenses/GPL-2.0-with-GCC-exception.html
[GPL-3.0+]: https://spdx.org/licenses/GPL-3.0+.html
[GPL-3.0-with-autoconf-exception]: https://spdx.org/licenses/GPL-3.0-with-autoconf-exception.html
[GPL-3.0-with-GCC-exception]: https://spdx.org/licenses/GPL-3.0-with-GCC-exception.html
[LGPL-2.1+]: https://spdx.org/licenses/LGPL-2.1+.html
[LGPL-3.0+]: https://spdx.org/licenses/LGPL-3.0+.html
[LGPL-2.0+]: https://spdx.org/licenses/LGPL-2.0+.html
[StandardML-NJ]: https://spdx.org/licenses/StandardML-NJ.html
[WXwindows]: https://spdx.org/licenses/WXwindows.html